==> nextcloud-13.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/it.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Commenti",
    "Edit comment" : "Modifica commento",
    "Delete comment" : "Elimina commento",
    "New comment …" : "Nuovo commento...",
    "Post" : "Commento",
    "Cancel" : "Annulla",
    "[Deleted user]" : "[Utente eliminato]",
    "No comments yet, start the conversation!" : "Ancora nessun commento, inizia la conversazione!",
    "More comments …" : "Altri commenti...",
    "Save" : "Salva",
    "Allowed characters {count} of {max}" : "Caratteri consentiti {count} di {max}",
    "Error occurred while retrieving comment with ID {id}" : "Si è verificato un errore durante il recupero del commento con ID {id}",
    "Error occurred while updating comment with id {id}" : "Si è verificato un errore durante il tentativo di aggiornamento del commento con id {id}",
    "Error occurred while posting comment" : "Si è verificato un errore durante la pubblicazione del commento.",
    "_%n unread comment_::_%n unread comments_" : ["%n commento non letto","%n commenti non letti"],
    "Comment" : "Commento",
    "You commented" : "Hai commentato",
    "%1$s commented" : "%1$s ha commentato",
    "{author} commented" : "{author} ha commentato",
    "You commented on %1$s" : "Hai commentato su %1$s",
    "You commented on {file}" : "Hai commentato su {file}",
    "%1$s commented on %2$s" : "%1$s ha commentato %2$s",
    "{author} commented on {file}" : "{author} ha commentato su {file}",
    "<strong>Comments</strong> for files" : "<strong>Commenti</strong> sui file",
    "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "Sei stato menzionato su \"%s\", in un commento di un utente che è stato eliminato",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Sei stato menzionato su \"{file}\", in un commento di un utente che è stato eliminato",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s ti ha menzionato in un commento su \"%2$s\"",
    "{user} mentioned you in a comment on “{file}”" : "{user} ti ha menzionato in un commento su \"{file}\".",
    "Unknown user" : "Utente sconosciuto",
    "A (now) deleted user mentioned you in a comment on “%s”" : "Un utente eliminato (ora) ti ha menzionato in un commento su \"%s\".",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "Un utente eliminato (ora) ti ha menzionato in un commento su \"{file}\"."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/it.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Commenti",
    "Edit comment" : "Modifica commento",
    "Delete comment" : "Elimina commento",
    "New comment …" : "Nuovo commento...",
    "Post" : "Commento",
    "Cancel" : "Annulla",
    "[Deleted user]" : "[Utente eliminato]",
    "No comments yet, start the conversation!" : "Ancora nessun commento, inizia la conversazione!",
    "More comments …" : "Altri commenti...",
    "Save" : "Salva",
    "Allowed characters {count} of {max}" : "Caratteri consentiti {count} di {max}",
    "Error occurred while retrieving comment with ID {id}" : "Si è verificato un errore durante il recupero del commento con ID {id}",
    "Error occurred while updating comment with id {id}" : "Si è verificato un errore durante il tentativo di aggiornamento del commento con id {id}",
    "Error occurred while posting comment" : "Si è verificato un errore durante la pubblicazione del commento.",
    "_%n unread comment_::_%n unread comments_" : ["%n commento non letto","%n commenti non letti"],
    "Comment" : "Commento",
    "You commented" : "Hai commentato",
    "%1$s commented" : "%1$s ha commentato",
    "{author} commented" : "{author} ha commentato",
    "You commented on %1$s" : "Hai commentato su %1$s",
    "You commented on {file}" : "Hai commentato su {file}",
    "%1$s commented on %2$s" : "%1$s ha commentato %2$s",
    "{author} commented on {file}" : "{author} ha commentato su {file}",
    "<strong>Comments</strong> for files" : "<strong>Commenti</strong> sui file",
    "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "Sei stato menzionato su \"%s\", in un commento di un utente che è stato eliminato",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Sei stato menzionato su \"{file}\", in un commento di un utente che è stato eliminato",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s ti ha menzionato in un commento su \"%2$s\"",
    "{user} mentioned you in a comment on “{file}”" : "{user} ti ha menzionato in un commento su \"{file}\".",
    "Files app plugin to add comments to files" : "Estensione dell'applicazione File per aggiungere commenti ai file",
    "Unknown user" : "Utente sconosciuto",
    "A (now) deleted user mentioned you in a comment on “%s”" : "Un utente eliminato (ora) ti ha menzionato in un commento su \"%s\".",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "Un utente eliminato (ora) ti ha menzionato in un commento su \"{file}\"."
},
"nplurals=2; plural=(n != 1);");
